/*
 * Copyright 2019 by Kappich Systemberatung Aachen
 * ALL RIGHTS RESERVED.
 */

package de.bsvrz.dav.daf.accessControl;

import java.util.EventListener;

/**
 * Listener, der bei Änderungen von Nutzerrechten ausgeführt wird
 * 
 * @see UserInfo#addChangeListener(AccessControlChangeListener) 
 * @see AccessControlManager#addChangeListener(AccessControlChangeListener) 
 *
 * @author Kappich Systemberatung
 */
@FunctionalInterface
public interface AccessControlChangeListener extends EventListener {

	/**
	 * Wird aufgerufen, wenn sich die Berechtigungen einen Benutzers (potentiell) geändert haben, beispielsweise durch eine geänderte Parametrierung oder weil sich Objektmengen geändert haben. 
	 * <p>Nachdem diese Methode aufgerufen wurde, muss der Nutzer der Klasse ggf. feststellen, welche Anmeldungen aktuell bestehen und neu verboten werden müssen, bzw. welche bisher verbotenen Anmeldungen nun erlaubt sind.</p>
	 * <p>Das Rechte-Management-Framework in den DAF-Funktionen bemüht sich, diese Methode nur einmal aufzurufen, selbst wenn sich mehrere Rechte eines Nutzers geändert haben.</p>
	 * 
	 * @param user Benutzer, dessen Rechte sich geändert haben
	 */
	void userPermissionsChanged(UserInfo user);
	
}
